==> dotnet9_9.0.110-9.0.9.orig.tar.xz: src/razor/src/Compiler/Microsoft.CodeAnalysis.Razor.Compiler/src/Language/Intermediate/ReferenceCaptureIntermediateNode.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#nullable disable

using System;
using Microsoft.AspNetCore.Razor.Language.CodeGeneration;
using Microsoft.AspNetCore.Razor.Language.Components;

namespace Microsoft.AspNetCore.Razor.Language.Intermediate;

public sealed class ReferenceCaptureIntermediateNode : IntermediateNode
{
    public ReferenceCaptureIntermediateNode(IntermediateToken identifierToken)
    {
        IdentifierToken = identifierToken ?? throw new ArgumentNullException(nameof(identifierToken));
        Source = IdentifierToken.Source;
    }

    public ReferenceCaptureIntermediateNode(IntermediateToken identifierToken, string componentCaptureTypeName)
        : this(identifierToken)
    {
        if (string.IsNullOrEmpty(componentCaptureTypeName))
        {
            throw new ArgumentException("Cannot be null or empty", nameof(componentCaptureTypeName));
        }

        IsComponentCapture = true;
        ComponentCaptureTypeName = componentCaptureTypeName;
    }

    public override IntermediateNodeCollection Children => IntermediateNodeCollection.ReadOnly;

    public IntermediateToken IdentifierToken { get; }

    public bool IsComponentCapture { get; }

    public string ComponentCaptureTypeName { get; set; }

    public string FieldTypeName => IsComponentCapture ? ComponentCaptureTypeName : $"global::{ComponentsApi.ElementReference.FullTypeName}";

    public string TypeName => $"global::System.Action<{FieldTypeName}>";

    public override void Accept(IntermediateNodeVisitor visitor)
    {
        if (visitor == null)
        {
            throw new ArgumentNullException(nameof(visitor));
        }

        visitor.VisitReferenceCapture(this);
    }

    public override void FormatNode(IntermediateNodeFormatter formatter)
    {
        if (formatter == null)
        {
            throw new ArgumentNullException(nameof(formatter));
        }

        formatter.WriteContent(IdentifierToken?.Content);

        formatter.WriteProperty(nameof(IdentifierToken), IdentifierToken?.Content);
        formatter.WriteProperty(nameof(ComponentCaptureTypeName), ComponentCaptureTypeName);
    }
}

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/razor/src/Compiler/Microsoft.CodeAnalysis.Razor.Compiler/src/Language/Intermediate/ReferenceCaptureIntermediateNode.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#nullable disable

using System;
using Microsoft.AspNetCore.Razor.Language.Components;

namespace Microsoft.AspNetCore.Razor.Language.Intermediate;

public sealed class ReferenceCaptureIntermediateNode : IntermediateNode
{
    public ReferenceCaptureIntermediateNode(IntermediateToken identifierToken)
    {
        IdentifierToken = identifierToken ?? throw new ArgumentNullException(nameof(identifierToken));
        Source = IdentifierToken.Source;
    }

    public ReferenceCaptureIntermediateNode(IntermediateToken identifierToken, string componentCaptureTypeName)
        : this(identifierToken)
    {
        if (string.IsNullOrEmpty(componentCaptureTypeName))
        {
            throw new ArgumentException("Cannot be null or empty", nameof(componentCaptureTypeName));
        }

        IsComponentCapture = true;
        ComponentCaptureTypeName = componentCaptureTypeName;
    }

    public override IntermediateNodeCollection Children => IntermediateNodeCollection.ReadOnly;

    public IntermediateToken IdentifierToken { get; }

    public bool IsComponentCapture { get; }

    /// <remarks>
    /// This is not <c>global::</c>-prefixed, for that consider using <see cref="FieldTypeName"/> instead.
    /// </remarks>
    public string ComponentCaptureTypeName { get; set; }

    public string FieldTypeName => IsComponentCapture
        ? TypeNameHelper.GetGloballyQualifiedNameIfNeeded(ComponentCaptureTypeName)
        : $"global::{ComponentsApi.ElementReference.FullTypeName}";

    public string TypeName => $"global::System.Action<{FieldTypeName}>";

    public override void Accept(IntermediateNodeVisitor visitor)
    {
        if (visitor == null)
        {
            throw new ArgumentNullException(nameof(visitor));
        }

        visitor.VisitReferenceCapture(this);
    }

    public override void FormatNode(IntermediateNodeFormatter formatter)
    {
        if (formatter == null)
        {
            throw new ArgumentNullException(nameof(formatter));
        }

        formatter.WriteContent(IdentifierToken?.Content);

        formatter.WriteProperty(nameof(IdentifierToken), IdentifierToken?.Content);
        formatter.WriteProperty(nameof(ComponentCaptureTypeName), ComponentCaptureTypeName);
    }
}
